## hvs16 example
daten <- as.data.frame(scan(what=list(run=0, A=0,B=0,C=0,D=0,E=0,rep1=0,rep2=0)))
1 1 -1 -1 -1 -1 69.8 72
2 -1 1 -1 -1 -1 66.4 67.4
3 -1 -1 1 -1 -1 83 68.6
4 -1 -1 -1 1 -1 16.2 23.4
5 -1 -1 -1 -1 1 46.1 33.6
6 1 1 1 -1 -1 68.6 65.5
7 1 1 -1 1 -1 6.8 7.2
8 1 1 -1 -1 1 15.6 19.1
9 1 -1 1 1 -1 11.1 7
10 1 -1 1 -1 1 19.8 20.3
11 1 -1 -1 1 1 3.7 4.7
12 -1 1 1 1 -1 5.8 3.9
13 -1 1 -1 1 1 2.6 4
14 -1 1 1 -1 1 42.2 23.2
15 -1 -1 1 1 1 1.8 5.2
16 1 1 1 1 1 3.1 3.4

dat1 <- daten[,2:7]
dat2 <- daten[,c(2:6,8)]
colnames(dat1)[6] <- "y"
colnames(dat2)[6] <- "y"
dat <- rbind(dat1,dat2)
daten$y <-(daten$rep1+daten$rep2)/2
daten$s <- daten$rep1-daten$rep2

require(FrF2)
## analysis with square root transformation
## Daniel plot analysis ignoring replications
#means analysis square root data (like in original paper)
dat$y <- sqrt(dat$y)
linmod <- lm(y~(A+B+C+D+E)^2, dat)
DanielPlot(linmod, half=TRUE, alpha=0.1)   ## very clear picture: D, E, DE, nothing else

## anova analysis using replications
summary(linmod)          ## many effects
b <- coef(linmod)[-1]

## needed for pure error slope
sterr <- sqrt(vcov(linmod)[2,2])  ## a representative standard error
                                  ## they are all the same
lm.pe <- summary(linmod)$sigma   ## this is a saturated model already
lm.pe/sqrt(32)  ## identical to sterr


## Daniel plot original data with error points
test <- halfnormal(linmod, main="Square root scale",alpha=0.1)    ## strong evidence for D,E,ED

mm <- test$mm
## look at automatically constructed model matrix for pure error
round(mm[,17:32],2)  ## no systematic pattern discernable on Windows 7, R 3.0.1
round(crossprod(mm),2)

## modify to conform to formula (10) from the paper
mm[,17:32] <- kronecker(c(-4,4),diag(16))
crossprod(mm)
## provide the linear model for this, and plot
linmod.recode <- lm(dat$y~.,as.data.frame(mm[,-1]))
b.recode <- coef(linmod.recode)[-1]
names(b.recode) <- gsub("`", "", names(b.recode))

## the Figure
par(mfrow=c(1,3))
halfnormal(b, labs=names(b), codes=names(b), main="(a) without extra points",alpha=0.1) 
abline(a=0, b=1/sterr)  
coefNEW <- halfnormal(linmod, 
     main="(b) with pure error points (*),\nautomated coding",alpha=0.1)$coef 
abline(a=0, b=1/sterr)  
coefNEW10 <- halfnormal(linmod.recode,pch=c(rep(1,15),rep(8,16)),
     main="(c) with pure error points (*),\ncoding of (10)",alpha=0.1, labs=names(b.recode))$coef 
abline(a=0, b=1/sterr)  

mm <- test$mm
## look at automatically constructed model matrix for pure error
round(mm[,17:32],2)  ## no systematic pattern discernable on Windows 7, R 3.0.1

## modify to conform to formula (11) from the paper
mm[,17:32] <- kronecker(c(-4,4),diag(16))
## provide the linear model for this, and plot

## all yield very similar results
dfe <- linmod$df.residual
## the estimated standard error (of a representative effect)
### equal to sqrt(lm.pe^2/32)

## excluding pure error
classic_Lenth <- ME.Lenth(b)
lapply(classic_Lenth$ME, function(obj) b[abs(b)>obj])

## including pure error, automated coding
NEW_ExDing <- ME.Lenth(coefNEW)
(signif.auto <- lapply(NEW_ExDing$ME, function(obj) coefNEW[abs(coefNEW)>obj]))

## including pure error, coding of formula (11)
NEW_ExDing10 <- ME.Lenth(coefNEW10)
(signif.10 <- lapply(NEW_ExDing10$ME, function(obj) coefNEW10[abs(coefNEW10)>obj]))

## in this example, there are only very few instances, 
## where the significance of a non-error effect 
## depends on the rotation 
mapply(setdiff, lapply(signif.auto, "names"), lapply(signif.10,function(obj) gsub("`","",names(obj))))
mapply(setdiff, lapply(signif.10,function(obj) gsub("`","",names(obj))), lapply(signif.auto, "names"))

## LW with nonlin
LW98_ExDing <- CME.LW98(b,sterr,dfe)
lapply(LW98_ExDing$CME, function(obj) b[abs(b)>obj])

## Edwards Mee with multiplier 1
EM1_ExDing <- CME.EM08(b,sterr,dfe,weight0=1)
lapply(EM1_ExDing$CME, function(obj) b[abs(b)>obj])

## Edwards Mee with multiplier 5
EM5_ExDing <- CME.EM08(b,sterr,dfe,weight0=5)
lapply(EM5_ExDing$CME, function(obj) b[abs(b)>obj])


